@@ -15,7 +15,7 @@ print.summary.ca <- function(x, ...){
   object <- x
   r.out  <- object$rows
   c.out  <- object$columns
-  if (!is.na(object$scree)[1]){
+  if (!is.null(object$scree)){
     cat("\n")
    # init:
     nchars <- 25
@@ -27,7 +27,8 @@ print.summary.ca <- function(x, ...){
     EV     <- rev[Dim]
     CUMEV  <- crev[Dim]
     if (length(rev)>1) {
-      st <- round(nchars * (rev - min(rev)) / diff(range(rev)), 0)
+  #    st <- round(nchars * (rev - min(rev)) / diff(range(rev)), 0)
+      st <- round(nchars * rev/sum(rev), 0)
       } else {
       st <- nchars
       }
@@ -110,6 +111,8 @@ print.summary.ca <- function(x, ...){
     }
 
  # print row/column summary:
+if (!is.null(object$rows)){
+	
   n1 <- dim(r.out)[1]
   n2 <- dim(r.out)[2]
   r.names <- dimnames(r.out)[[2]]
@@ -125,7 +128,13 @@ print.summary.ca <- function(x, ...){
   r.nn <- c(r.nn, "")
   colnames(r.new) <- r.nn
   rownames(r.new) <- 1:n1
+  cat("\nRows:\n")
+  print(as.matrix(r.new), quote = FALSE, right = TRUE)
+  
+}
 
+if (!is.null(object$columns)){
+	
   n1 <- dim(c.out)[1]
   n2 <- dim(c.out)[2]
   c.names <- dimnames(c.out)[[2]]
@@ -142,11 +151,10 @@ print.summary.ca <- function(x, ...){
   colnames(c.new) <- c.nn
   rownames(c.new) <- 1:n1
 
-  cat("\nRows:\n")
-  print(as.matrix(r.new), quote = FALSE, right = TRUE)
   cat("\nColumns:\n")
   print(as.matrix(c.new), quote = FALSE, right = TRUE)
-  cat("\n")
+}
+#  cat("\n")
 
 
   }
